Slot: exact mappings - LinkML Model

# Slot: exact mappings

A list of terms from different schemas or terminology systems that have identical meaning.

URI: linkml:exact_mappings

## Domain and Range

None → 0..* Uriorcurie

## Parents

- is_a: mappings

## Children

## Used by

- ClassDefinition
- Definition
- Element
- EnumDefinition
- SchemaDefinition
- SlotDefinition
- SubsetDefinition
- TypeDefinition

## Other properties

Mappings: |  | skos:exactMatch